@@ -16,7 +16,7 @@ Usage::
     session_client: FISClient = session.client("fis")
     ```
 """
-from mypy_boto3_fis.client import FISClient
+from .client import FISClient
 
 Client = FISClient
 
